@@ -434,8 +434,8 @@ class WaveformParameters:
 
         return {
             "q": self.mass_ratio,
-            "Lambda1": self.lambda_1,
-            "Lambda2": self.lambda_2,
+            "LambdaAl2": self.lambda_1,
+            "LambdaBl2": self.lambda_2,
             "chi1": self.chi_1,
             "chi2": self.chi_2,
             "M": self.dataset.total_mass,
@@ -446,7 +446,6 @@ class WaveformParameters:
             "domain": 1,  # Fourier domain
             "srate_interp": srate,
             "df": self.dataset.delta_f_hz * self.dataset.mass_sum_seconds,
-            "interp_FD_waveform": 1,
             "inclination": 0.0,
             "output_hpc": "no",
             "time_shift_FD": "yes",
@@ -608,6 +607,7 @@ class ParameterGenerator(ABC, Iterator):
     """
 
     number_of_free_parameters: int = 5
+    parameter_set_cls = ParameterSet
 
     def __init__(self, dataset: "Dataset", seed: Optional[int] = None, **kwargs):
 
@@ -721,6 +721,10 @@ class Dataset:
             the class as opposed to an instance since the parameter generator
             needs to reference the dataset and therefure must be created after it.
             Defaults to UniformParameterGenerator.
+    parameter_ranges: ParameterRanges
+            Ranges for the parameters to be generated.
+            Defaults to ParameterRanges(), which will use the
+            parameters defined as defaults in that class.
     parameter_generator : Optional[ParameterGenerator]
             Certain parameter generators should not be regenerated each time;
             if this is the case, then pass the parameter generator here.
@@ -863,6 +867,12 @@ class Dataset:
                 self.delta_f_hz,
             )
 
+    @property
+    def parameter_set_cls(self):
+        if self.parameter_generator is None:
+            return ParameterGenerator.parameter_set_cls
+        return self.parameter_generator.parameter_set_cls
+
     def optimal_df_hz(
         self, power_of_two: bool = True, margin_percent: float = 8.0
     ) -> float:
@@ -974,6 +984,10 @@ class Dataset:
         ----------
         eta : float
                 Mass ratio of the binary
+        total_mass : Optional[float]
+                Total mass of the binary.
+                Defaults to None, in which case the `total_mass`
+                attribute of the Dataset will be used.
         """
 
         if total_mass is None:
@@ -1079,7 +1093,7 @@ class Dataset:
 
         return (
             self.frequencies,
-            ParameterSet(parameter_array),
+            self.parameter_set_cls(parameter_array),
             residuals,
         )
 
